@@ -30,6 +30,8 @@ import sys
 from framework import main, Stop
 
 from upgrade import UpgradeCommand
+from artifacts import DownloadCommand
+from version import Version
 
 
 def entry_point():
@@ -38,7 +40,10 @@ def entry_point():
     if Stop is raised, calls sys.exit()
     """
     try:
-        main(items=[("upgrade", UpgradeCommand)])
+        main(items=[
+            (UpgradeCommand.NAME, UpgradeCommand),
+            (DownloadCommand.NAME, DownloadCommand),
+            (Version.NAME, Version)])
     except Stop, stop:
         print stop,
         sys.exit(stop.rc)
